..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

Enums
#####

Component related enumerations
==============================

.. autoclass:: nirahmq.enums.Platform
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.Category
    :members:
    :member-order: bysource
    :undoc-members:


Device class enumerations
=========================

.. autoclass:: nirahmq.enums.BinarySensorClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.ButtonClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.CoverClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.EventClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HumidifierClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.NumberClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.SensorClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.SensorStateClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.SwitchClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.UpdateClass
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.ValveClass
    :members:
    :member-order: bysource
    :undoc-members:


Miscellaneous enumerations
==========================

.. autoclass:: nirahmq.enums.TemperatureUnit
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.Precision
    :members:
    :member-order: bysource
    :undoc-members:


Component specific enumerations
===============================

.. autoclass:: nirahmq.enums.AlarmControlPanelCode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.AlarmControlPanelFeature
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.AlarmControlPanelState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.ImageEncoding
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.CoverState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.DeviceTrackerSource
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.DeviceTriggerType
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.DeviceTriggerSubtype
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HumidifierMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HumidifierAction
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HVACAction
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HVACFanMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HVACMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.HVACPresetMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.LawnMowerState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.LightColorMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.LockState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.NumberMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.TextMode
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.VacuumFeature
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.VacuumState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.VacuumFanSpeed
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.ValveState
    :members:
    :member-order: bysource
    :undoc-members:


.. autoclass:: nirahmq.enums.WaterHeaterMode
    :members:
    :member-order: bysource
    :undoc-members:
